==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/KafkaMirrorMakerTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaMirrorMakerTemplateFluent<A extends KafkaMirrorMakerTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getDeployment();
    public ResourceTemplate buildDeployment();
    public A withDeployment(ResourceTemplate deployment);
    public Boolean hasDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> withNewDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> withNewDeploymentLike(ResourceTemplate item);
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> editDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> withNewPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public KafkaMirrorMakerTemplateFluent.PodNested<A> editPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> editOrNewPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildMirrorMakerContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getMirrorMakerContainer();
    public ContainerTemplate buildMirrorMakerContainer();
    public A withMirrorMakerContainer(ContainerTemplate mirrorMakerContainer);
    public Boolean hasMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> withNewMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> withNewMirrorMakerContainerLike(ContainerTemplate item);
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> editMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> editOrNewMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> editOrNewMirrorMakerContainerLike(ContainerTemplate item);

    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<KafkaMirrorMakerTemplateFluent.DeploymentNested<N>>{

        
    public N and();    public N endDeployment();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<KafkaMirrorMakerTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface MirrorMakerContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<N>>{

        
    public N and();    public N endMirrorMakerContainer();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/KafkaMirrorMakerTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaMirrorMakerTemplateFluent<A extends KafkaMirrorMakerTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public DeploymentTemplate getDeployment();
    public DeploymentTemplate buildDeployment();
    public A withDeployment(DeploymentTemplate deployment);
    public Boolean hasDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> withNewDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> withNewDeploymentLike(DeploymentTemplate item);
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> editDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public KafkaMirrorMakerTemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(DeploymentTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> withNewPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public KafkaMirrorMakerTemplateFluent.PodNested<A> editPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> editOrNewPod();
    public KafkaMirrorMakerTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildMirrorMakerContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getMirrorMakerContainer();
    public ContainerTemplate buildMirrorMakerContainer();
    public A withMirrorMakerContainer(ContainerTemplate mirrorMakerContainer);
    public Boolean hasMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> withNewMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> withNewMirrorMakerContainerLike(ContainerTemplate item);
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> editMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> editOrNewMirrorMakerContainer();
    public KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<A> editOrNewMirrorMakerContainerLike(ContainerTemplate item);

    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,DeploymentTemplateFluent<KafkaMirrorMakerTemplateFluent.DeploymentNested<N>>{

        
    public N and();    public N endDeployment();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<KafkaMirrorMakerTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<KafkaMirrorMakerTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface MirrorMakerContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<KafkaMirrorMakerTemplateFluent.MirrorMakerContainerNested<N>>{

        
    public N and();    public N endMirrorMakerContainer();
}


}
